@@ -1,5 +1,5 @@
 from .hash_object import hash_object
-from .hash_object import hash_object as hash
-from .hash_object import hash_object as smart_hash
+from .hash_object import hash
+from .hash_object import smart_hash
 from .make_hashable import make_hashable
 from .to_bytes import to_bytes
